summaryrefslogtreecommitdiffstats
path: root/quanta/parts/kafka/undoredo.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/parts/kafka/undoredo.h')
-rw-r--r--quanta/parts/kafka/undoredo.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/quanta/parts/kafka/undoredo.h b/quanta/parts/kafka/undoredo.h
index 6280a67f..6464c46d 100644
--- a/quanta/parts/kafka/undoredo.h
+++ b/quanta/parts/kafka/undoredo.h
@@ -95,17 +95,17 @@ public:
/**
* TODO:REMOVE
* For non-XmlEnd Node deletion without its tqchildren.
* @param tqchildrenNumber The number of tqchildren which are moved up
* at the location where was the deleted Node.
*/
- void setChildrenMovedUp(int tqchildrenNumber) {m_tqchildrenMovedUp = tqchildrenNumber;}
+ void setChildrenMovedUp(int childrenNumber) {m_childrenMovedUp = childrenNumber;}
/**
* TODO:REMOVE
* @return Returns the number of childs which were moved up.
*/
- int tqchildrenMovedUp() {return m_tqchildrenMovedUp;}
+ int childrenMovedUp() {return m_childrenMovedUp;}
/**
* TODO:REMOVE
@@ -139,7 +139,7 @@ public:
NodeTreeRemoved,
//Moving a Node from one location to another. Implemented.
NodeMoved,
- //Moving a Node and its tqchildren from one location to another.
+ //Moving a Node and its children from one location to another.
NodeAndChildsMoved
};
@@ -148,7 +148,7 @@ private:
TQValueList<int> m_location, m_finalLocation;
Node *m_node;
Tag *m_tag;
- int m_tqchildrenMovedUp;
+ int m_childrenMovedUp;
int m_neighboursMovedDown;
};
@@ -95,17 +95,17 @@ public:
/**
* TODO:REMOVE
- * For non-XmlEnd Node deletion without its tqchildren.
- * @param tqchildrenNumber The number of tqchildren which are moved up
+ * For non-XmlEnd Node deletion without its children.
+ * @param childrenNumber The number of children which are moved up
* at the location where was the deleted Node.
*/